@@ -1,6 +1,6 @@
 /*
  * backend.h -- Interface exported by XBoard back end
- * $Id: backend.h,v 1.46 2001/02/05 20:32:32 mann Exp $
+ * $Id: backend.h,v 1.47 2001/12/09 23:02:59 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -75,7 +75,7 @@ void InitBackEnd2 P((void));
 int IsPromotion P((int fromX, int fromY, int toX, int toY));
 int PieceForSquare P((int x, int y));
 int OKToStartUserMove P((int x, int y));
-void Reset P((int redraw));
+void Reset P((int redraw, int init));
 void ResetGameEvent P((void));
 int LoadGame P((FILE *f, int n, char *title, int useList));
 int LoadGameFromFile P((char *filename, int n, char *title, int useList));
